@@ -10,12 +10,13 @@ from bluer_ugv.README import (
     beast,
     eagle,
     fire,
-    parts,
     robin,
     root,
     shield,
-    sparrow,
+    arzhang,
+    rangin,
     swallow,
+    UGVs,
 )
 
 
@@ -36,17 +37,15 @@ def build() -> bool:
             ),
             macros=readme.get("macros", {}),
         )
-        for readme in [
-            {"path": "../docs"},
-        ]
-        + root.docs
+        for readme in root.docs
         + beast.docs
         + eagle.docs
         + fire.docs
         + robin.docs
         + shield.docs
-        + sparrow.docs
+        + arzhang.docs
         + swallow.docs
         + alias.docs
-        + parts.docs
+        + UGVs.docs
+        + rangin.docs
     )
