@@ -1,16 +1,16 @@
-from bluer_ugv.README.consts import assets2
-
 NAME = "bluer_ugv"
 
 ICON = "🐬"
 
 DESCRIPTION = f"{ICON} AI x UGV."
 
-VERSION = "6.1038.1"
+VERSION = "7.70.1"
 
 REPO_NAME = "bluer-ugv"
 
-MARQUEE = f"{assets2}/bluer-sparrow/VID-20250905-WA0014_1.gif"
+MARQUEE = (
+    "https://github.com/kamangir/assets2/raw/main/arzhang/VID-20250905-WA0014_1.gif"
+)
 
 
 ALIAS = "@ugv"
