@@ -5,8 +5,8 @@ load_env(__name__)
 load_config(__name__)
 
 
-BLUER_BEAST_MODEL = get_env(
-    "BLUER_BEAST_MODEL",
+BLUER_UGV_BEAST_MODEL = get_env(
+    "BLUER_UGV_BEAST_MODEL",
 )
 
 BLUER_UGV_CAMERA_TRAINING_PERIOD = get_env(
@@ -56,3 +56,23 @@ BLUER_UGV_ULTRASONIC_SENSOR_DANGER_THRESHOLD = get_env(
     "BLUER_UGV_ULTRASONIC_SENSOR_DANGER_THRESHOLD",
     500.0,
 )
+
+BLUER_UGV_ULTRASONIC_SENSOR_ENABLED = get_env(
+    "BLUER_UGV_ULTRASONIC_SENSOR_ENABLED",
+    0,
+)
+
+BLUER_UGV_ULTRASONIC_SENSOR_MAX_M = get_env(
+    "BLUER_UGV_ULTRASONIC_SENSOR_",
+    0.8,
+)
+
+BLUER_UGV_ULTRASONIC_SENSOR_KEEP_LOG = get_env(
+    "BLUER_UGV_ULTRASONIC_SENSOR_KEEP_LOG",
+    1,
+)
+
+BLUER_UGV_ULTRASONIC_SENSOR_LOG = get_env(
+    "BLUER_UGV_ULTRASONIC_SENSOR_LOG",
+    1,
+)
