@@ -3,8 +3,8 @@ from typing import List
 from bluer_options.terminal import show_usage, xtra
 
 review_args = [
-    "[--frame_count <100>]",
-    "[--gif 1]",
+    "[--frame_count <-1>]",
+    "[--gif 0]",
     "[--rm_blank 0]",
 ]
 
