@@ -43,6 +43,8 @@ class ClassicalKeyboard:
 
         self.special_key: bool = False
 
+        self.ultrasound_enabled: bool = True
+
     def update(self) -> bool:
         self.last_key = ""
 
@@ -119,13 +121,28 @@ class ClassicalKeyboard:
             self.special_key = False
             logger.info("mode: {}.".format(self.mode.name.lower()))
 
+        # ultrasound
+        ultrasound_enabled = self.ultrasound_enabled
+        if keyboard.is_pressed("n"):
+            self.ultrasound_enabled = False
+
+        if keyboard.is_pressed("m"):
+            self.ultrasound_enabled = True
+
+        if ultrasound_enabled != self.ultrasound_enabled:
+            self.special_key = False
+            logger.info(
+                "ultrasound: {}.".format(
+                    "enabled" if self.ultrasound_enabled else "disabled"
+                )
+            )
+
         # special key
         if keyboard.is_pressed("z") and not self.special_key:
             self.special_key = True
             logger.info("🪄 special key enabled.")
 
         if self.special_key:
-            for led in self.leds.leds.values():
-                led["state"] = not led["state"]
+            self.leds.flash_all()
 
         return True
