@@ -1,5 +1,9 @@
 from RPi import GPIO  # type: ignore
 
+from bluer_options import string
+from bluer_options.timing.classes import Timing
+from bluer_objects.env import abcli_object_name
+from bluer_objects.metadata import post_to_object
 from bluer_sbc.env import BLUER_SBC_ENV, BLUER_SBC_SWALLOW_HAS_STEERING
 
 from bluer_ugv.swallow.session.classical.camera import (
@@ -19,6 +23,9 @@ from bluer_ugv.swallow.session.classical.motor import (
     ClassicalSteeringMotor,
 )
 from bluer_ugv.swallow.session.classical.setpoint.classes import ClassicalSetPoint
+from bluer_ugv.swallow.session.classical.ultrasonic_sensor.classes import (
+    ClassicalUltrasonicSensor,
+)
 from bluer_ugv.env import BLUER_UGV_MOUSEPAD_ENABLED
 from bluer_ugv.logger import logger
 
@@ -30,6 +37,8 @@ class ClassicalSession:
     ):
         self.object_name = object_name
 
+        GPIO.setmode(GPIO.BCM)
+
         self.leds = ClassicalLeds()
 
         self.setpoint = ClassicalSetPoint(
@@ -47,6 +56,11 @@ class ClassicalSession:
             setpoint=self.setpoint,
         )
 
+        self.ultrasonic_sensor = ClassicalUltrasonicSensor(
+            setpoint=self.setpoint,
+            keyboard=self.keyboard,
+        )
+
         self.push_button = ClassicalPushButton(
             leds=self.leds,
         )
@@ -103,7 +117,11 @@ class ClassicalSession:
             )
         )
 
+        self.timing = Timing()
+
     def cleanup(self):
+        self.ultrasonic_sensor.stop()
+
         for thing in [
             self.motor1,
             self.motor2,
@@ -113,15 +131,29 @@ class ClassicalSession:
 
         GPIO.cleanup()
 
+        self.timing.calculate()
+        loop_frequency = round(
+            1 / self.timing.stats["session.update"]["average"],
+            2,
+        )
+        self.timing.log()
+        post_to_object(
+            abcli_object_name,
+            "timing",
+            self.timing.as_dict,
+        )
+        logger.info(
+            "loop frequency: {}".format(string.pretty_frequency(loop_frequency))
+        )
+        post_to_object(
+            abcli_object_name,
+            "loop_frequency",
+            loop_frequency,
+        )
+
         logger.info(f"{self.__class__.__name__}.cleanup")
 
     def initialize(self) -> bool:
-        try:
-            GPIO.setmode(GPIO.BCM)
-        except Exception as e:
-            logger.error(e)
-            return False
-
         return all(
             thing.initialize()
             for thing in [
@@ -134,15 +166,23 @@ class ClassicalSession:
         )
 
     def update(self) -> bool:
-        return all(
-            thing.update()
-            for thing in [
-                self.keyboard,
-                self.push_button,
-                self.camera,
-                self.setpoint,
-                self.motor1,
-                self.motor2,
-                self.leds,
-            ]
-        )
+        self.timing.start("session.update")
+
+        for thing in [
+            self.keyboard,
+            self.push_button,
+            self.camera,
+            self.setpoint,
+            self.motor1,
+            self.motor2,
+            self.leds,
+        ]:
+            self.timing.start(thing.__class__.__name__)
+
+            if not thing.update():
+                return False
+
+            self.timing.stop(thing.__class__.__name__)
+
+        self.timing.stop("session.update")
+        return True
