@@ -10,11 +10,12 @@ from bluer_objects import file, path
 from bluer_objects.graphics.gif import generate_animated_gif
 from bluer_objects.graphics.signature import add_signature
 
-from bluer_ugv.logger import logger
+from bluer_ugv import env
 from bluer_ugv.swallow.session.classical.ultrasonic_sensor.detection import (
     Detection,
 )
 from bluer_ugv.host import signature
+from bluer_ugv.logger import logger
 
 
 class UltrasonicSensorDetectionLog:
@@ -33,7 +34,7 @@ class UltrasonicSensorDetectionLog:
         log: bool = True,
         rm_blank: bool = True,
     ) -> bool:
-        for func, name in zip(
+        for func, name, filename in zip(
             [
                 lambda detection: int(detection.detection),
                 lambda detection: int(detection.echo_detected),
@@ -46,6 +47,12 @@ class UltrasonicSensorDetectionLog:
                 "pulse (ms)",
                 "distance(mm)",
             ],
+            [
+                "ultrasonic-sensor-detection",
+                "ultrasonic-sensor-echo-detection",
+                "ultrasonic-sensor-pulse-ms",
+                "ultrasonic-sensor-distance-mm",
+            ],
         ):
             plt.figure(figsize=(5, 5))
             plt.plot(
@@ -83,9 +90,7 @@ class UltrasonicSensorDetectionLog:
             if not file.save_fig(
                 objects.path_of(
                     object_name=object_name,
-                    filename="{}.png".format(
-                        name.replace(" ", "-").replace("(", "-").replace(")", "-")
-                    ),
+                    filename=f"{filename}.png",
                 ),
                 log=log,
             ):
@@ -167,7 +172,16 @@ class UltrasonicSensorDetectionLog:
                 image,
                 header=[
                     " | ".join(
-                        ["ultrasonic-sensor"]
+                        [
+                            "ultrasonic-sensor",
+                            "max distance: {:.2f} mm".format(max_m * 1000),
+                            "warning: {:.2f} mm".format(
+                                env.BLUER_UGV_ULTRASONIC_SENSOR_WARNING_THRESHOLD
+                            ),
+                            "danger: {:.2f} mm".format(
+                                env.BLUER_UGV_ULTRASONIC_SENSOR_DANGER_THRESHOLD
+                            ),
+                        ]
                         + [detection.as_str(short=True) for detection in detections]
                         + objects.signature(
                             "frame #{:04d}/{}".format(
